@@ -31,7 +31,6 @@
 #include "../types/structuretype.h"
 #include "../expressionparser.h"
 
-using namespace KTextEditor;
 using namespace KDevelop;
 
 QTEST_MAIN(Php::TestExpressionParser)
@@ -55,7 +54,7 @@ void TestExpressionParser::newClass()
     DUChainWriteLocker lock(DUChain::lock());
 
     ExpressionParser p(true);
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$i"), DUContextPointer(top), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$i"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(res.type());
     QCOMPARE(StructureType::Ptr::staticCast(res.type())->qualifiedIdentifier(), QualifiedIdentifier("a"));
 }
@@ -73,7 +72,7 @@ void TestExpressionParser::newSelf()
     ExpressionParser p(true);
     ExpressionEvaluationResult res = p.evaluateType( QByteArray("new self()"),
                                         DUContextPointer(top->childContexts().first()->childContexts().last()),
-                                        SimpleCursor(0, 30));
+                                        CursorInRevision(0, 30));
     QVERIFY(res.type());
     QCOMPARE(StructureType::Ptr::staticCast(res.type())->qualifiedIdentifier(), QualifiedIdentifier("a"));
 }
@@ -89,10 +88,10 @@ void TestExpressionParser::memberVariable()
     DUChainWriteLocker lock(DUChain::lock());
 
     ExpressionParser p(true);
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$i->foo"), DUContextPointer(top), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$i->foo"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(res.type());
     QCOMPARE(res.allDeclarations().count(), 1);
-    QCOMPARE(res.allDeclarations().first(), top->childContexts().first()->localDeclarations().first());
+    QCOMPARE(res.allDeclarations().first().data(), top->childContexts().first()->localDeclarations().first());
     QCOMPARE(StructureType::Ptr::staticCast(res.type())->qualifiedIdentifier(), QualifiedIdentifier("a"));
 }
 void TestExpressionParser::memberFunction()
@@ -106,12 +105,12 @@ void TestExpressionParser::memberFunction()
     DUChainWriteLocker lock(DUChain::lock());
 
     ExpressionParser p(true);
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$i->foo()"), DUContextPointer(top), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$i->foo()"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(res.type());
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type())->dataType() == IntegralType::TypeVoid);
     QCOMPARE(res.allDeclarations().size(), 1);
-    QCOMPARE(res.allDeclarations().first(), top->childContexts().first()->localDeclarations().first());
+    QCOMPARE(res.allDeclarations().first().data(), top->childContexts().first()->localDeclarations().first());
 }
 void TestExpressionParser::globalFunction()
 {
@@ -124,11 +123,11 @@ void TestExpressionParser::globalFunction()
     DUChainWriteLocker lock(DUChain::lock());
 
     ExpressionParser p(true);
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("foo"), DUContextPointer(top), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("foo"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(res.type());
     QVERIFY(FunctionType::Ptr::dynamicCast(res.type()));
     QCOMPARE(res.allDeclarations().count(), 1);
-    QCOMPARE(res.allDeclarations().first(), top->localDeclarations().first());
+    QCOMPARE(res.allDeclarations().first().data(), top->localDeclarations().first());
 }
 
 void TestExpressionParser::chainCall()
@@ -146,11 +145,11 @@ void TestExpressionParser::chainCall()
     QVERIFY(fn->returnType()->equals(top->localDeclarations().first()->abstractType().unsafeData()));
 
     ExpressionParser p(true);
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$a->foo()"), DUContextPointer(top), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$a->foo()"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(res.type());
     QVERIFY(res.type()->equals(top->localDeclarations().first()->abstractType().unsafeData()));
 
-    res = p.evaluateType(QByteArray("$a->foo()->foo()->foo()"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("$a->foo()->foo()->foo()"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(res.type());
     QVERIFY(res.type()->equals(top->localDeclarations().first()->abstractType().unsafeData()));
 }
@@ -166,9 +165,9 @@ void TestExpressionParser::thisObject()
 
     DUContext* funContext = top->childContexts().first()->localDeclarations().first()->internalContext();
     ExpressionParser p(true);
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$this"), DUContextPointer(funContext), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("$this"), DUContextPointer(funContext), CursorInRevision(1, 0));
     QCOMPARE(res.allDeclarations().count(), 1);
-    QCOMPARE(res.allDeclarations().first(), top->localDeclarations().first());
+    QCOMPARE(res.allDeclarations().first().data(), top->localDeclarations().first());
     QVERIFY(res.type());
     QVERIFY(StructureType::Ptr::dynamicCast(res.type()));
     QCOMPARE(StructureType::Ptr::dynamicCast(res.type())->declaration(top), top->localDeclarations().first());
@@ -186,39 +185,39 @@ void TestExpressionParser::integralTypes()
 
     ExpressionParser p(true);
 
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("123"), DUContextPointer(top), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("123"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeInt));
 
-    res = p.evaluateType(QByteArray("123.1"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("123.1"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeFloat));
 
-    res = p.evaluateType(QByteArray("\"asdf\""), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("\"asdf\""), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeString));
 
-    res = p.evaluateType(QByteArray("\"as $foo df\""), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("\"as $foo df\""), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeString));
 
-    res = p.evaluateType(QByteArray("'asdf'"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("'asdf'"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeString));
 
-    res = p.evaluateType(QByteArray("true"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("true"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeBoolean));
 
-    res = p.evaluateType(QByteArray("TRUE"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("TRUE"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeBoolean));
 
-    res = p.evaluateType(QByteArray("null"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("null"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeNull));
 
-    res = p.evaluateType(QByteArray("NULL"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("NULL"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeNull));
 }
@@ -235,7 +234,7 @@ void TestExpressionParser::newObject()
 
     ExpressionParser p(true);
 
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("new A();"), DUContextPointer(top), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("new A();"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(StructureType::Ptr::dynamicCast(res.type()));
     QCOMPARE(StructureType::Ptr::staticCast(res.type())->declaration(top), top->localDeclarations().first());
 }
@@ -252,27 +251,27 @@ void TestExpressionParser::cast()
 
     ExpressionParser p(true);
 
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("(string)$foo"), DUContextPointer(top), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("(string)$foo"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeString);
 
-    res = p.evaluateType(QByteArray("(int)$foo"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("(int)$foo"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeInt);
 
-    res = p.evaluateType(QByteArray("(double)$foo"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("(double)$foo"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeFloat);
 
-    res = p.evaluateType(QByteArray("(bool)$foo"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("(bool)$foo"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeBoolean);
 
-    res = p.evaluateType(QByteArray("(array)$foo"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("(array)$foo"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeArray);
 
-    res = p.evaluateType(QByteArray("(object)$foo"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("(object)$foo"), DUContextPointer(top), CursorInRevision(1, 0));
     kDebug() << res.type();
     kDebug() << res.type()->toString();
     QVERIFY(StructureType::Ptr::dynamicCast(res.type()));
@@ -291,43 +290,43 @@ void TestExpressionParser::operations()
 
     ExpressionParser p(true);
 
-    ExpressionEvaluationResult res = p.evaluateType(QByteArray("'1' . '1'"), DUContextPointer(top), SimpleCursor(1, 0));
+    ExpressionEvaluationResult res = p.evaluateType(QByteArray("'1' . '1'"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeString);
 
-    res = p.evaluateType(QByteArray("1 . 1"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("1 . 1"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeString);
 
-    res = p.evaluateType(QByteArray("1 + 1"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("1 + 1"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeInt);
 
-    res = p.evaluateType(QByteArray("'1' + '1'"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("'1' + '1'"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeInt);
 
-    res = p.evaluateType(QByteArray("$foo .= '1'"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("$foo .= '1'"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeString);
 
-    res = p.evaluateType(QByteArray("$foo .= 1"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("$foo .= 1"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeString);
 
-    res = p.evaluateType(QByteArray("$foo += 1"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("$foo += 1"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeInt);
 
-    res = p.evaluateType(QByteArray("$foo += '1'"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("$foo += '1'"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeInt);
 
-    res = p.evaluateType(QByteArray("$foo *= 1"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("$foo *= 1"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeInt);
 
-    res = p.evaluateType(QByteArray("$foo *= '1'"), DUContextPointer(top), SimpleCursor(1, 0));
+    res = p.evaluateType(QByteArray("$foo *= '1'"), DUContextPointer(top), CursorInRevision(1, 0));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QVERIFY(IntegralType::Ptr::staticCast(res.type())->dataType() == IntegralType::TypeInt);
 }
@@ -350,19 +349,19 @@ void TestExpressionParser::findArg()
     QVERIFY(top->childContexts().at(2)->type() != DUContext::Function);
 
     ExpressionEvaluationResult res = p.evaluateType(QByteArray("$arg"), DUContextPointer(top->childContexts().last()),
-                                                    SimpleCursor(0, 47));
+                                                    CursorInRevision(0, 47));
     QVERIFY(IntegralType::Ptr::dynamicCast(res.type()));
     QCOMPARE(IntegralType::Ptr::staticCast(res.type())->dataType(), static_cast<uint>(IntegralType::TypeMixed));
 
     res = p.evaluateType(QByteArray("$bar"), DUContextPointer(top->childContexts().last()),
-                         SimpleCursor(0, 47));
+                         CursorInRevision(0, 47));
     ReferenceType::Ptr type = ReferenceType::Ptr::dynamicCast(res.type());
     QVERIFY(type);
     QVERIFY(IntegralType::Ptr::dynamicCast(type->baseType()));
     QCOMPARE(IntegralType::Ptr::staticCast(type->baseType())->dataType(), static_cast<uint>(IntegralType::TypeMixed));
 
     res = p.evaluateType(QByteArray("$a"), DUContextPointer(top->childContexts().last()),
-                         SimpleCursor(0, 47));
+                         CursorInRevision(0, 47));
     type = ReferenceType::Ptr::dynamicCast(res.type());
     QVERIFY(type);
     QVERIFY(StructureType::Ptr::dynamicCast(type->baseType()));
@@ -384,7 +383,7 @@ void TestExpressionParser::array()
     ExpressionParser p(true);
     QCOMPARE(top->localDeclarations().first()->abstractType().cast<IntegralType>()->dataType(), static_cast<uint>(IntegralType::TypeArray));
 
-    ExpressionEvaluationResult res = p.evaluateType("$b = $a[0]", DUContextPointer(top), SimpleCursor(0, 22));
+    ExpressionEvaluationResult res = p.evaluateType("$b = $a[0]", DUContextPointer(top), CursorInRevision(0, 22));
     QVERIFY(res.type().cast<IntegralType>());
     QEXPECT_FAIL("", "we'd need advanced array support to know that [0] returns a string...", Continue);
     QCOMPARE(res.type().cast<IntegralType>()->dataType(), static_cast<uint>(IntegralType::TypeString));
